==> kubernetes-model-core-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/GlusterfsPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class GlusterfsPersistentVolumeSourceFluentImpl<A extends GlusterfsPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GlusterfsPersistentVolumeSourceFluent<A> {

    private String endpoints;
    private String endpointsNamespace;
    private String path;
    private Boolean readOnly;

    public GlusterfsPersistentVolumeSourceFluentImpl() {
    }

    public GlusterfsPersistentVolumeSourceFluentImpl(GlusterfsPersistentVolumeSource instance) {
        this.withEndpoints(instance.getEndpoints()); 
        this.withEndpointsNamespace(instance.getEndpointsNamespace()); 
        this.withPath(instance.getPath()); 
        this.withReadOnly(instance.getReadOnly()); 
    }

    public String getEndpoints() {
        return this.endpoints;
    }

    public A withEndpoints(String endpoints) {
        this.endpoints=endpoints; return (A) this;
    }

    public Boolean hasEndpoints() {
        return this.endpoints != null;
    }

    public A withNewEndpoints(String arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(StringBuilder arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(StringBuffer arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public String getEndpointsNamespace() {
        return this.endpointsNamespace;
    }

    public A withEndpointsNamespace(String endpointsNamespace) {
        this.endpointsNamespace=endpointsNamespace; return (A) this;
    }

    public Boolean hasEndpointsNamespace() {
        return this.endpointsNamespace != null;
    }

    public A withNewEndpointsNamespace(String arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(StringBuilder arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(StringBuffer arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public Boolean isReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GlusterfsPersistentVolumeSourceFluentImpl that = (GlusterfsPersistentVolumeSourceFluentImpl) o;
        if (endpoints != null ? !endpoints.equals(that.endpoints) :that.endpoints != null) return false;
        if (endpointsNamespace != null ? !endpointsNamespace.equals(that.endpointsNamespace) :that.endpointsNamespace != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(endpoints,  endpointsNamespace,  path,  readOnly,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/GlusterfsPersistentVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class GlusterfsPersistentVolumeSourceFluentImpl<A extends GlusterfsPersistentVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements GlusterfsPersistentVolumeSourceFluent<A> {

    private String endpoints;
    private String endpointsNamespace;
    private String path;
    private Boolean readOnly;

    public GlusterfsPersistentVolumeSourceFluentImpl() {
    }

    public GlusterfsPersistentVolumeSourceFluentImpl(GlusterfsPersistentVolumeSource instance) {
        this.withEndpoints(instance.getEndpoints()); 
        this.withEndpointsNamespace(instance.getEndpointsNamespace()); 
        this.withPath(instance.getPath()); 
        this.withReadOnly(instance.getReadOnly()); 
    }

    public String getEndpoints() {
        return this.endpoints;
    }

    public A withEndpoints(String endpoints) {
        this.endpoints=endpoints; return (A) this;
    }

    public Boolean hasEndpoints() {
        return this.endpoints != null;
    }

    public A withNewEndpoints(StringBuilder arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(int[] arg1,int arg2,int arg3) {
        return (A)withEndpoints(new String(arg1, arg2, arg3));
    }

    public A withNewEndpoints(char[] arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(StringBuffer arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(byte[] arg1,int arg2) {
        return (A)withEndpoints(new String(arg1, arg2));
    }

    public A withNewEndpoints(byte[] arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public A withNewEndpoints(char[] arg1,int arg2,int arg3) {
        return (A)withEndpoints(new String(arg1, arg2, arg3));
    }

    public A withNewEndpoints(byte[] arg1,int arg2,int arg3) {
        return (A)withEndpoints(new String(arg1, arg2, arg3));
    }

    public A withNewEndpoints(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withEndpoints(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewEndpoints(String arg1) {
        return (A)withEndpoints(new String(arg1));
    }

    public String getEndpointsNamespace() {
        return this.endpointsNamespace;
    }

    public A withEndpointsNamespace(String endpointsNamespace) {
        this.endpointsNamespace=endpointsNamespace; return (A) this;
    }

    public Boolean hasEndpointsNamespace() {
        return this.endpointsNamespace != null;
    }

    public A withNewEndpointsNamespace(StringBuilder arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(int[] arg1,int arg2,int arg3) {
        return (A)withEndpointsNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewEndpointsNamespace(char[] arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(StringBuffer arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(byte[] arg1,int arg2) {
        return (A)withEndpointsNamespace(new String(arg1, arg2));
    }

    public A withNewEndpointsNamespace(byte[] arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public A withNewEndpointsNamespace(char[] arg1,int arg2,int arg3) {
        return (A)withEndpointsNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewEndpointsNamespace(byte[] arg1,int arg2,int arg3) {
        return (A)withEndpointsNamespace(new String(arg1, arg2, arg3));
    }

    public A withNewEndpointsNamespace(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withEndpointsNamespace(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewEndpointsNamespace(String arg1) {
        return (A)withEndpointsNamespace(new String(arg1));
    }

    public String getPath() {
        return this.path;
    }

    public A withPath(String path) {
        this.path=path; return (A) this;
    }

    public Boolean hasPath() {
        return this.path != null;
    }

    public A withNewPath(StringBuilder arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(int[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(char[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(byte[] arg1,int arg2) {
        return (A)withPath(new String(arg1, arg2));
    }

    public A withNewPath(byte[] arg1) {
        return (A)withPath(new String(arg1));
    }

    public A withNewPath(char[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3) {
        return (A)withPath(new String(arg1, arg2, arg3));
    }

    public A withNewPath(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withPath(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewPath(String arg1) {
        return (A)withPath(new String(arg1));
    }

    public Boolean getReadOnly() {
        return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly) {
        this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly() {
        return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1) {
        return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GlusterfsPersistentVolumeSourceFluentImpl that = (GlusterfsPersistentVolumeSourceFluentImpl) o;
        if (endpoints != null ? !endpoints.equals(that.endpoints) :that.endpoints != null) return false;
        if (endpointsNamespace != null ? !endpointsNamespace.equals(that.endpointsNamespace) :that.endpointsNamespace != null) return false;
        if (path != null ? !path.equals(that.path) :that.path != null) return false;
        if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(endpoints,  endpointsNamespace,  path,  readOnly,  super.hashCode());
    }

}
